@@ -99,7 +99,7 @@ has warning_str =>
 	required => 0,
 );
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 # ------------------------------------------------
 
@@ -1379,6 +1379,9 @@ L<http://perldoc.perl.org/perlrequick.html>
 
 L<http://perldoc.perl.org/perlrebackslash.html>
 
+L<http://perldoc.perl.org/perl5140delta.html#Regular-Expressions>. This is when stringification
+changed to return (?^...).
+
 L<https://www.endpoint.com/blog/2018/01/23/regular-expression-inconsistencies-with-unicode>
 
 L<http://www.nntp.perl.org/group/perl.perl5.porters/2016/02/msg234642.html>. Regular Expression
@@ -1517,15 +1520,19 @@ comment							::= non_close_parenthesis*
 flag_thingy						::= open_parenthesis query flag_set_1
 									| open_parenthesis query_caret flag_set_2 close_parenthesis
 
-flag_set_1						::= flag_sequence
+flag_set_1						::= flag_sequence	# adlupimnsx-imnsx
 
-flag_set_2						::= flag_sequence
+flag_set_2						::= flag_sequence	# alupimnsx
 
 # 3: (?:pattern)	Eg: (?:(?<n>foo)|(?<n>bar))\k<n>
 #  & (?adluimnsx-imnsx:pattern)
 #  & (?^aluimnsx:pattern)
 
 colon_thingy					::= colon_prefix pattern_sequence close_parenthesis
+									| open_parenthesis query flag_set_3 colon pattern_sequence close_parenthesis
+									| open_parenthesis query_caret positive_flags colon pattern_sequence close_parenthesis
+
+flag_set_3						::= flag_sequence	# adluimnsx-imnsx
 
 # 99. Non-extended patterns.
 
